@@ -20,9 +20,10 @@
 #' @param threads number of concurrent threads to use for checking.
 #'   It defaults to the option \code{"Ncpus"} or \code{1} if unset.
 #' @param check_dir the directory in which the package is checked
+#' @param revdep_pkg Optional name of a package for which this check is
+#'   checking the reverse dependencies of. This is normally passed in from
+#'   \code{\link{revdep_check}}, and is used only for logging.
 #' @return invisible \code{TRUE} if successful and no ERRORs or WARNINGS,
-#' @importFrom tools package_dependencies
-#' @importFrom parallel mclapply
 #' @export
 #' @examples
 #' \dontrun{
@@ -33,7 +34,9 @@
 #' }
 check_cran <- function(pkgs, libpath = file.path(tempdir(), "R-lib"),
   srcpath = libpath, bioconductor = FALSE, type = getOption("pkgType"),
-  threads = getOption("Ncpus", 1), check_dir = tempfile("check_cran")) {
+  threads = getOption("Ncpus", 1), check_dir = tempfile("check_cran"),
+  revdep_pkg = NULL) {
+
   stopifnot(is.character(pkgs))
   if (length(pkgs) == 0) return()
 
@@ -71,7 +74,7 @@ check_cran <- function(pkgs, libpath = file.path(tempdir(), "R-lib"),
   }
 
   # Install missing dependencies
-  deps <- unique(unlist(package_dependencies(pkgs, packages(),
+  deps <- unique(unlist(tools::package_dependencies(pkgs, packages(),
     which = "all")))
   to_install <- setdiff(deps, installed.packages()[, 1])
   known <- intersect(to_install, rownames(available_bin))
@@ -127,15 +130,8 @@ check_cran <- function(pkgs, libpath = file.path(tempdir(), "R-lib"),
     results
   }
 
-  if (getRversion() <= '2.15.2' && threads >= length(pkgs)) {
-    threads <- max(length(pkgs) - 1L, 1L)
-    message("Reducing number of threads to ", threads,
-      " (number of packages to check minus one) due to a bug in mclapply in",
-      " R <= 2.15.2")
-  }
-
-  results <- mclapply(seq_along(pkgs), check_pkg, mc.preschedule = FALSE,
-    mc.cores = threads)
+  results <- parallel::mclapply(seq_along(pkgs), check_pkg,
+    mc.preschedule = FALSE, mc.cores = threads)
 
   names(results) <- pkgs
 
@@ -145,9 +141,9 @@ check_cran <- function(pkgs, libpath = file.path(tempdir(), "R-lib"),
   }
 
   # Collect the output
-  collect_check_results(check_dir)
+  collect_check_results(check_dir, revdep_pkg)
 
-  invisible(results)
+  invisible(list(path = check_dir, results = results))
 }
 
 parse_check_results <- function(path) {
@@ -166,7 +162,7 @@ parse_check_results <- function(path) {
 
 # Collects all the results from running check_cran and puts in a
 # directory results/ under the top level tempdir.
-collect_check_results <- function(topdir) {
+collect_check_results <- function(topdir, revdep_pkg) {
   # Directory for storing results
   rdir <- file.path(topdir, "results")
   if (dir.exists(rdir)) {
@@ -217,7 +213,18 @@ collect_check_results <- function(topdir) {
   on.exit(close(summary_out))
 
   sink(summary_out)
-  print(sessionInfo())
+  if (!is.null(revdep_pkg)) {
+    sha <- packageDescription(revdep_pkg)$RemoteSha
+    if (!is.null(sha)) sha <- paste0("Commit ", sha, "\n")
+
+    cat("=========================================================================\n",
+        "Reverse dependency check for ", revdep_pkg, " ",
+        as.character(packageVersion(revdep_pkg)), "\n",
+        sha,
+        "=========================================================================\n",
+        sep = "")
+  }
+  print(session_info())
   cat("\n")
   sink()
 
