@@ -22,8 +22,7 @@ check_dir <- function(x) {
   }
 
   # Normalise path and strip trailing slashes
-  x <- gsub("\\\\", "/", x, fixed = TRUE)
-  x <- sub("/*$", "", x)
+  x <- normalise_path(x)
 
   if (!file.exists(x)) {
     stop("Can't find directory ", x, call. = FALSE)
@@ -35,6 +34,12 @@ check_dir <- function(x) {
   x
 }
 
+normalise_path <- function(x) {
+  x <- sub("\\\\+$", "/", x)
+  x <- sub("/*$", "", x)
+  x
+}
+
 # Load package DESCRIPTION into convenient form.
 load_pkg_description <- function(path) {
   path <- normalizePath(path)
