@@ -77,16 +77,17 @@ test_that("Extra files copied and removed", {
 
 test_that("vignettes built on install", {
   # Make sure it fails if we build without installing
-  expect_error(build_vignettes("testVignettesBuilt"), 
+  expect_error(build_vignettes("testVignettesBuilt"),
     "there is no package called")
-  
-  install("testVignettesBuilt", reload = FALSE, quiet = TRUE)
+
+  install("testVignettesBuilt", reload = FALSE, quiet = TRUE,
+    build_vignettes = TRUE)
   unlink("testVignettesBuilt/vignettes/new.tex")
   unlink("testVignettesBuilt/vignettes/.build.timestamp")
-  
+
   vigs <- vignette(package = "testVignettesBuilt")$results
   expect_equal(nrow(vigs), 1)
   expect_equal(vigs[3], "new")
-  
+
   suppressMessages(remove.packages("testVignettesBuilt"))
-})
\ No newline at end of file
+})
